==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealRulesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Rules that can be defined for auto-heal.
 * @property actions Actions to be executed when a rule is triggered.
 * @property triggers Conditions that describe when to execute the auto-heal actions.
 */
public data class AutoHealRulesArgs(
    public val actions: Output<AutoHealActionsArgs>? = null,
    public val triggers: Output<AutoHealTriggersArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealRulesArgs =
        com.pulumi.azurenative.web.inputs.AutoHealRulesArgs.builder()
            .actions(actions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .triggers(triggers?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AutoHealRulesArgs].
 */
@PulumiTagMarker
public class AutoHealRulesArgsBuilder internal constructor() {
    private var actions: Output<AutoHealActionsArgs>? = null

    private var triggers: Output<AutoHealTriggersArgs>? = null

    /**
     * @param value Actions to be executed when a rule is triggered.
     */
    @JvmName("yomanwkbkuqstghh")
    public suspend fun actions(`value`: Output<AutoHealActionsArgs>) {
        this.actions = value
    }

    /**
     * @param value Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("fmlcrnqytvvcvrmu")
    public suspend fun triggers(`value`: Output<AutoHealTriggersArgs>) {
        this.triggers = value
    }

    /**
     * @param value Actions to be executed when a rule is triggered.
     */
    @JvmName("uwxgpnxscchrbodo")
    public suspend fun actions(`value`: AutoHealActionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param argument Actions to be executed when a rule is triggered.
     */
    @JvmName("jyeaakkyjeancleu")
    public suspend fun actions(argument: suspend AutoHealActionsArgsBuilder.() -> Unit) {
        val toBeMapped = AutoHealActionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param value Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("kxjwydwyoxfmmfme")
    public suspend fun triggers(`value`: AutoHealTriggersArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggers = mapped
    }

    /**
     * @param argument Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("gujrspfysflkamwc")
    public suspend fun triggers(argument: suspend AutoHealTriggersArgsBuilder.() -> Unit) {
        val toBeMapped = AutoHealTriggersArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.triggers = mapped
    }

    internal fun build(): AutoHealRulesArgs = AutoHealRulesArgs(
        actions = actions,
        triggers = triggers,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/AutoHealRulesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.AutoHealRulesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 * Rules that can be defined for auto-heal.
 * @property actions Actions to be executed when a rule is triggered.
 * @property triggers Conditions that describe when to execute the auto-heal actions.
 */
public data class AutoHealRulesArgs(
    public val actions: Output<AutoHealActionsArgs>? = null,
    public val triggers: Output<AutoHealTriggersArgs>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.AutoHealRulesArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.AutoHealRulesArgs =
        com.pulumi.azurenative.web.inputs.AutoHealRulesArgs.builder()
            .actions(actions?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) }))
            .triggers(triggers?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [AutoHealRulesArgs].
 */
@PulumiTagMarker
public class AutoHealRulesArgsBuilder internal constructor() {
    private var actions: Output<AutoHealActionsArgs>? = null

    private var triggers: Output<AutoHealTriggersArgs>? = null

    /**
     * @param value Actions to be executed when a rule is triggered.
     */
    @JvmName("kunnnhbvwfrencjo")
    public suspend fun actions(`value`: Output<AutoHealActionsArgs>) {
        this.actions = value
    }

    /**
     * @param value Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("xqqfddogdbmrbnlb")
    public suspend fun triggers(`value`: Output<AutoHealTriggersArgs>) {
        this.triggers = value
    }

    /**
     * @param value Actions to be executed when a rule is triggered.
     */
    @JvmName("jnjpkyonowtmacnv")
    public suspend fun actions(`value`: AutoHealActionsArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.actions = mapped
    }

    /**
     * @param argument Actions to be executed when a rule is triggered.
     */
    @JvmName("meyjjfsqjpqswprg")
    public suspend fun actions(argument: suspend AutoHealActionsArgsBuilder.() -> Unit) {
        val toBeMapped = AutoHealActionsArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.actions = mapped
    }

    /**
     * @param value Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("dltfvehbsftksdci")
    public suspend fun triggers(`value`: AutoHealTriggersArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggers = mapped
    }

    /**
     * @param argument Conditions that describe when to execute the auto-heal actions.
     */
    @JvmName("ccmvdfkwqlimjnfs")
    public suspend fun triggers(argument: suspend AutoHealTriggersArgsBuilder.() -> Unit) {
        val toBeMapped = AutoHealTriggersArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.triggers = mapped
    }

    internal fun build(): AutoHealRulesArgs = AutoHealRulesArgs(
        actions = actions,
        triggers = triggers,
    )
}
